thorn.django.rest_framework.views — Thorn 1.3.0 documentation

# thorn.django.rest_framework.views

- thorn.django.rest_framework.views

## thorn.django.rest_framework.views

API endpoints for users to create and manage their webhook subscriptions.

class `thorn.django.rest_framework.views.` `SubscriberList`(**kwargs)

  List and create new subscriptions for the currently logged in user.

  `get_queryset`()
  `model`

    alias of `Subscriber`

  `perform_create`(serializer)
  `permission_classes`
  `serializer_class`

    alias of `SubscriberSerializer`

class `thorn.django.rest_framework.views.` `SubscriberDetail`(**kwargs)

  Update, delete or get details for specific subscription owned by the currently logged in user.

  `get_object`()
  `lookup_field` = u'uuid'
  `model`

    alias of `Subscriber`

  `permission_classes`
  `serializer_class`

    alias of `SubscriberSerializer`